@@ -7,8 +7,8 @@ JOB_TYPE="${JOB_TYPE:-}"
 
 if [ "${JOB_TYPE}" == "travis" ]; then
     go get -v -t ./...
-    go get github.com/mattn/goveralls
-    go get -v github.com/onsi/ginkgo/ginkgo
+    go install github.com/mattn/goveralls@latest
+    go install github.com/onsi/ginkgo/ginkgo@latest
     go get -v github.com/onsi/gomega
     go get -u github.com/evanphx/json-patch
     go mod vendor
@@ -17,7 +17,7 @@ if [ "${JOB_TYPE}" == "travis" ]; then
     KUBEVIRT_CLIENT_GO_SCHEME_REGISTRATION_VERSION=v1 ginkgo -r -covermode atomic -outputdir=./coverprofiles -coverprofile=cover.coverprofile ${PACKAGE_PATH}
 else
     test_path="tests/func-tests"
-    (cd $test_path; GOFLAGS= go get github.com/onsi/ginkgo/ginkgo)
+    (cd $test_path; go install github.com/onsi/ginkgo/ginkgo@latest)
     (cd $test_path; GOFLAGS= go get github.com/onsi/gomega)
     (cd $test_path; go mod  tidy; go mod vendor)
     test_out_path=${test_path}/_out
