@@ -17,7 +17,8 @@ import (
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/tools/reference"
-	cdiv1beta1 "kubevirt.io/containerized-data-importer/pkg/apis/core/v1beta1"
+
+	cdiv1beta1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
 	hcov1beta1 "github.com/kubevirt/hyperconverged-cluster-operator/pkg/apis/hco/v1beta1"
 	"github.com/kubevirt/hyperconverged-cluster-operator/pkg/controller/common"
@@ -593,6 +594,75 @@ var _ = Describe("CDI Operand", func() {
 			})
 		})
 
+		Context("Test UninstallStrategy", func() {
+
+			It("should set BlockUninstallIfWorkloadsExist if missing HCO CR", func() {
+				existingResource, err := NewCDI(hco)
+				Expect(err).ToNot(HaveOccurred())
+				hco.Spec.UninstallStrategy = nil
+
+				cl := commonTestUtils.InitClient([]runtime.Object{hco, existingResource})
+				handler := (*genericOperand)(newCdiHandler(cl, commonTestUtils.GetScheme()))
+				res := handler.ensure(req)
+				Expect(res.Err).To(BeNil())
+
+				foundCdi := &cdiv1beta1.CDI{}
+				Expect(
+					cl.Get(context.TODO(),
+						types.NamespacedName{Name: existingResource.Name, Namespace: existingResource.Namespace},
+						foundCdi),
+				).To(BeNil())
+
+				Expect(foundCdi.Spec.UninstallStrategy).ToNot(BeNil())
+				Expect(*foundCdi.Spec.UninstallStrategy).To(Equal(cdiv1beta1.CDIUninstallStrategyBlockUninstallIfWorkloadsExist))
+			})
+
+			It("should set BlockUninstallIfWorkloadsExist if set on HCO CR", func() {
+				existingResource, err := NewCDI(hco)
+				Expect(err).ToNot(HaveOccurred())
+				uninstallStrategy := hcov1beta1.HyperConvergedUninstallStrategyBlockUninstallIfWorkloadsExist
+				hco.Spec.UninstallStrategy = &uninstallStrategy
+
+				cl := commonTestUtils.InitClient([]runtime.Object{hco, existingResource})
+				handler := (*genericOperand)(newCdiHandler(cl, commonTestUtils.GetScheme()))
+				res := handler.ensure(req)
+				Expect(res.Err).To(BeNil())
+
+				foundCdi := &cdiv1beta1.CDI{}
+				Expect(
+					cl.Get(context.TODO(),
+						types.NamespacedName{Name: existingResource.Name, Namespace: existingResource.Namespace},
+						foundCdi),
+				).To(BeNil())
+
+				Expect(foundCdi.Spec.UninstallStrategy).ToNot(BeNil())
+				Expect(*foundCdi.Spec.UninstallStrategy).To(Equal(cdiv1beta1.CDIUninstallStrategyBlockUninstallIfWorkloadsExist))
+			})
+
+			It("should set BlockUninstallIfRemoveWorkloads if set on HCO CR", func() {
+				existingResource, err := NewCDI(hco)
+				Expect(err).ToNot(HaveOccurred())
+				uninstallStrategy := hcov1beta1.HyperConvergedUninstallStrategyRemoveWorkloads
+				hco.Spec.UninstallStrategy = &uninstallStrategy
+
+				cl := commonTestUtils.InitClient([]runtime.Object{hco, existingResource})
+				handler := (*genericOperand)(newCdiHandler(cl, commonTestUtils.GetScheme()))
+				res := handler.ensure(req)
+				Expect(res.Err).To(BeNil())
+
+				foundCdi := &cdiv1beta1.CDI{}
+				Expect(
+					cl.Get(context.TODO(),
+						types.NamespacedName{Name: existingResource.Name, Namespace: existingResource.Namespace},
+						foundCdi),
+				).To(BeNil())
+
+				Expect(foundCdi.Spec.UninstallStrategy).ToNot(BeNil())
+				Expect(*foundCdi.Spec.UninstallStrategy).To(Equal(cdiv1beta1.CDIUninstallStrategyRemoveWorkloads))
+			})
+
+		})
+
 		It("should override CDI config field", func() {
 			expectedResource, err := NewCDI(hco)
 			Expect(err).ToNot(HaveOccurred())
@@ -1069,12 +1139,14 @@ var _ = Describe("CDI Operand", func() {
 
 		Context("Config Reader Role", func() {
 			It("should do nothing if exists", func() {
-				expectedRole := NewConfigReaderRoleForCR(hco, hco.Namespace)
+				expectedRole := NewCdiConfigReaderRole(hco)
 				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRole})
 
-				handler := (*genericOperand)(newConfigReaderRoleHandler(cl, commonTestUtils.GetScheme()))
-				res := handler.ensure(req)
-				Expect(res.Err).ToNot(HaveOccurred())
+				handlers, err := NewConfigReaderRoleHandler(logger, cl, commonTestUtils.GetScheme(), hco)
+				Expect(handlers).To(HaveLen(1))
+				Expect(err).To(BeNil())
+				res := handlers[0].ensure(req)
+				Expect(res.Err).NotTo(HaveOccurred())
 
 				foundRole := &rbacv1.Role{}
 				Expect(
@@ -1088,15 +1160,17 @@ var _ = Describe("CDI Operand", func() {
 			})
 
 			It("should update if labels are missing", func() {
-				expectedRole := NewConfigReaderRoleForCR(hco, hco.Namespace)
+				expectedRole := NewCdiConfigReaderRole(hco)
 				expectedLabels := expectedRole.Labels
 				expectedRole.Labels = nil
 
 				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRole})
 
-				handler := (*genericOperand)(newConfigReaderRoleHandler(cl, commonTestUtils.GetScheme()))
-				res := handler.ensure(req)
-				Expect(res.Err).ToNot(HaveOccurred())
+				handlers, err := NewConfigReaderRoleHandler(logger, cl, commonTestUtils.GetScheme(), hco)
+				Expect(handlers).To(HaveLen(1))
+				Expect(err).To(BeNil())
+				res := handlers[0].ensure(req)
+				Expect(res.Err).NotTo(HaveOccurred())
 
 				foundRole := &rbacv1.Role{}
 				Expect(
@@ -1111,13 +1185,15 @@ var _ = Describe("CDI Operand", func() {
 
 		Context("Config Reader Role Binding", func() {
 			It("should do nothing if exists", func() {
-				expectedRoleBinding := NewConfigReaderRoleBindingForCR(hco, hco.Namespace)
+				expectedRoleBinding := NewCdiConfigReaderRoleBinding(hco)
 
 				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRoleBinding})
 
-				handler := (*genericOperand)(newConfigReaderRoleBindingHandler(cl, commonTestUtils.GetScheme()))
-				res := handler.ensure(req)
-				Expect(res.Err).ToNot(HaveOccurred())
+				handlers, err := newConfigReaderRoleBindingHandler(logger, cl, commonTestUtils.GetScheme(), hco)
+				Expect(handlers).To(HaveLen(1))
+				Expect(err).To(BeNil())
+				res := handlers[0].ensure(req)
+				Expect(res.Err).NotTo(HaveOccurred())
 
 				foundRoleBinding := &rbacv1.RoleBinding{}
 				Expect(
@@ -1130,15 +1206,17 @@ var _ = Describe("CDI Operand", func() {
 			})
 
 			It("should update if labels are missing", func() {
-				expectedRoleBinding := NewConfigReaderRoleBindingForCR(hco, hco.Namespace)
+				expectedRoleBinding := NewCdiConfigReaderRoleBinding(hco)
 				expectedLabels := expectedRoleBinding.Labels
 				expectedRoleBinding.Labels = nil
 
 				cl := commonTestUtils.InitClient([]runtime.Object{hco, expectedRoleBinding})
 
-				handler := (*genericOperand)(newConfigReaderRoleBindingHandler(cl, commonTestUtils.GetScheme()))
-				res := handler.ensure(req)
-				Expect(res.Err).ToNot(HaveOccurred())
+				handlers, err := newConfigReaderRoleBindingHandler(logger, cl, commonTestUtils.GetScheme(), hco)
+				Expect(handlers).To(HaveLen(1))
+				Expect(err).To(BeNil())
+				res := handlers[0].ensure(req)
+				Expect(res.Err).NotTo(HaveOccurred())
 
 				foundRoleBinding := &rbacv1.RoleBinding{}
 				Expect(
