@@ -4,10 +4,12 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
-	conditionsv1 "github.com/openshift/custom-resource-status/conditions/v1"
 	"os"
+	"reflect"
 	"strings"
 
+	conditionsv1 "github.com/openshift/custom-resource-status/conditions/v1"
+
 	jsonpatch "github.com/evanphx/json-patch"
 	"sigs.k8s.io/controller-runtime/pkg/controller/controllerutil"
 
@@ -112,6 +114,8 @@ func (h *genericOperand) handleExistingCr(req *common.HcoRequest, key client.Obj
 	}
 
 	if updated {
+		// update resourceVersions of objects in relatedObjects
+		req.StatusDirty = true
 		return res.SetUpdated().SetOverwritten(overwritten)
 	}
 
@@ -142,6 +146,14 @@ func (h *genericOperand) addCrToTheRelatedObjectList(req *common.HcoRequest, fou
 		return err
 	}
 
+	existingRef, err := objectreferencesv1.FindObjectReference(req.Instance.Status.RelatedObjects, *objectRef)
+	if err != nil {
+		return err
+	}
+	if existingRef != nil && !reflect.DeepEqual(existingRef, *objectRef) {
+		req.StatusDirty = true
+	}
+
 	err = objectreferencesv1.SetObjectReference(&req.Instance.Status.RelatedObjects, *objectRef)
 	if err != nil {
 		return err
